==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pl\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Karta czasu pracy"
 ,"Karty czasu pracy"
 ,"Karty czasu pracy"
 ,"Karty czasu pracy"

]
, "Account"
: "Konto"

, "Time Account (Number - Title)"
: "Konto czasu (numer - tytuł)"

, "Billable"
: "Do przeliczenia"

, "Cleared in"
: "Przeliczone w"

, "Invoice"
: ""

, "Cleared"
: "Przeliczone"

, "Date"
: "Data"

, "Start time"
: "Czas rozpoczęcia"

, "End time"
: ""

, "Duration"
: "Czas trwania"

, "Description"
: "Opis"

, "Type"
: ""

, "Time Account closed"
: "Konto godzin zamknięte"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Contract"
: "Kontrakt"

, "Title"
: "Tytuł"

, "Number"
: "Numer"

, "Price"
: ""

, "Status"
: "Status"

, "Billed"
: "Przeliczone"

, "Cleared at"
: ""

, "Booking deadline"
: "Ostateczny termin rezerwacji"

, "Responsible"
: ""

, "Cost Center"
: "Centrum kosztów"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Konto godzin"
 ,"konta godzin"
 ,"konta godzin"
 ,"konta godzin"

]
, "Time Account - Status"
: "Status konta godzin"

, "closed"
: "zakończone"

, "open"
: "otwarte"

, "Not a valid time"
: "Nieprawidłowy czas"

, "Time Account - Billed"
: "Czas pracy - zliczony"

, "not yet billed"
: "jeszcze nieprzeliczone"

, "to bill"
: "przelicz"

, "billed"
: "przeliczone"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Przeliczone w"

, "Select Time Account..."
: "Zaznacz konto godzin..."

, "Start"
: "Początek"

, "not set"
: "nieustawiony"

, "End"
: ""

, "Enter description..."
: "Wprowadź opis..."

, "Need for Clarification"
: ""

, "Failed"
: "Próba nieudana"

, "Could not save {0}."
: "Zapisanie {0} było niemożliwe."

, "Booking deadline for this Timeaccount has been exceeded."
: "Ostateczny termin rezerwacji dla niniejszego konta godzin został przekroczony."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Zarezerwuj własne"

, "The grant to add Timesheets to this Timeaccount"
: "Uprawnienia do dodawania kart czasu pracy do konta godzin"

, "View All"
: "Pokaż wszystko"

, "The grant to view Timesheets of other users"
: "Uprawnienia do podglądu kart czasu pracy innych użytkowników"

, "Book All"
: "Zarezerwuj wszystkie"

, "The grant to add Timesheets for other users"
: "Uprawnienia do dodawania kart czasu pracy innych użytkowników"

, "Manage Clearing"
: "Edytuj przeliczalne"

, "The grant to manage clearing of Timesheets"
: "Uprawnienia do czyszczenia kart czasu pracy"

, "without contract"
: "bez kontraktu"

, "without responsible"
: ""

, "timeframe"
: "przedział czasu"

, "summary"
: "streszczenie"

, "Total Timesheets"
: "Wszystkie karty czasu pracy"

, "Billable Timesheets"
: "Karty czasu pracy do przeliczenia"

, "Total Time"
: "Łączny czas"

, "Time of Billable Timesheets"
: "Czas z kart czasu pracy gotowych do przeliczenia"

, "Detail"
: "Szczegół"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Eksportuj karty czasu pracy"

, "Export as ODS"
: "Eksportuj jako ODS"

, "Export as CSV"
: "Eksportuj jako CSV"

, "Export as ..."
: "Eksportuj jako ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Jednostka"

, "Unit Price"
: "Cena jednostkowa"

, "Budget"
: "Budżet"

, "Timesheets are billable"
: "Karty czasu pracy gotowe do przeliczenia"

, "Access"
: "Dostępność"

, "Permissions"
: "Uprawnienia"

, "Show closed"
: "Pokaż zakończone"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Konfiguracja eksportu kart czasu pracy do formatu ODS"

, "Use this configuration for the timesheet ODS export."
: "Użyj niniejszej konfiguracji podczas eksportu kart czasu pracy do formatu ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "domyślnie"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "Brak"

, "last week"
: "ubiegły tydzień"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Zarządzaj kontami godzin"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Dodaj, edytuj i usuń konta godzin (razem ze wszystkimi uprawnieniami do kart czasu pracy)"

, "Add timeaccounts"
: "Dodaj konta godzin"

, "Manage shared timeaccount favorites"
: "Zarządzaj wspólnymi ulubionymi śledzenia czasu"

, "Create or update shared timeaccount favorites"
: "Utwórz albo uaktualnij wspólne ulubione śledzenia czasu"

, "Manage shared timesheet favorites"
: "Zarządzaj wspólnymi ulubionymi śledzenia czasu"

, "Create or update shared timesheet favorites"
: "Utwórz albo uaktualnij wspólne ulubione śledzenia czasu"

, "My Timesheets today"
: "Moje, dzisiejsze karty czasu pracy"

, "My Timesheets this week"
: "Moje karty czasu pracy z bieżącego tygodnia"

, "My Timesheets last week"
: "Moje karty czasu pracy z ubiegłego tygodnia"

, "My Timesheets this month"
: "Moje karty czasu pracy z bieżącego miesiąca"

, "My Timesheets last month"
: "Moje karty czasu pracy z ubiegłego miesiąca"

, "Timeaccounts to bill"
: "Karty czasu pracy do przeliczenia"

, "Timeaccounts not yet billed"
: "Nieprzeliczone konta godzin"

, "Timeaccounts already billed"
: "Przeliczone konta godzin"

, "Timetracker"
: "Zliczanie czasu"

, "Timesheet"
: "Karta czasu pracy"

, "Timeaccount"
: ""

, "Time Account"
: "Konto godzin"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "przedział czasu"

, "summary"
: "streszczenie"

, "Total Timesheets"
: "Wszystkie karty czasu pracy"

, "Billable Timesheets"
: "Karty czasu pracy do przeliczenia"

, "Total Time"
: "Łączny czas"

, "Time of Billable Timesheets"
: "Czas z kart czasu pracy gotowych do przeliczenia"

, "Description"
: "Opis"

, "Detail"
: "Szczegół"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Eksportuj karty czasu pracy"

, "Export as ODS"
: "Eksportuj jako ODS"

, "Export as CSV"
: "Eksportuj jako CSV"

, "Export as ..."
: "Eksportuj jako ..."

, "Timesheet, Timesheets"
: [
  "Karta czasu pracy"
 ,"Karty czasu pracy"
 ,"Karty czasu pracy"
 ,"Karty czasu pracy"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Failed"
: "Próba nieudana"

, "Could not save {0}."
: "Zapisanie {0} było niemożliwe."

, "Booking deadline for this Timeaccount has been exceeded."
: "Ostateczny termin rezerwacji dla niniejszego konta godzin został przekroczony."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Kontrakt"

, "without contract"
: "bez kontraktu"

, "Add New Timeaccount"
: ""

, "Unit"
: "Jednostka"

, "Unit Price"
: "Cena jednostkowa"

, "Factor"
: ""

, "Budget"
: "Budżet"

, "Status"
: "Status"

, "closed"
: "zakończone"

, "open"
: "otwarte"

, "Cleared In"
: "Przeliczone w"

, "Cleared at"
: ""

, "Cost Center"
: "Centrum kosztów"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Karty czasu pracy gotowe do przeliczenia"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Konto godzin"
 ,"konta godzin"
 ,"konta godzin"
 ,"konta godzin"

]
, "Number"
: "Numer"

, "Title"
: "Tytuł"

, "Access"
: "Dostępność"

, "Permissions"
: "Uprawnienia"

, "Time Account - Billed"
: "Czas pracy - zliczony"

, "not yet billed"
: "jeszcze nieprzeliczone"

, "to bill"
: "przelicz"

, "billed"
: "przeliczone"

, "Time Account - Status"
: "Status konta godzin"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Zarezerwuj własne"

, "The grant to add Timesheets to this Timeaccount"
: "Uprawnienia do dodawania kart czasu pracy do konta godzin"

, "View All"
: "Pokaż wszystko"

, "The grant to view Timesheets of other users"
: "Uprawnienia do podglądu kart czasu pracy innych użytkowników"

, "Book All"
: "Zarezerwuj wszystkie"

, "The grant to add Timesheets for other users"
: "Uprawnienia do dodawania kart czasu pracy innych użytkowników"

, "Manage Clearing"
: "Edytuj przeliczalne"

, "The grant to manage clearing of Timesheets"
: "Uprawnienia do czyszczenia kart czasu pracy"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Pokaż zakończone"

, "Timesheets ODS export configuration"
: "Konfiguracja eksportu kart czasu pracy do formatu ODS"

, "Use this configuration for the timesheet ODS export."
: "Użyj niniejszej konfiguracji podczas eksportu kart czasu pracy do formatu ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "domyślnie"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "Brak"

, "last week"
: "ubiegły tydzień"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Przeliczone w"

, "Billed"
: "Przeliczone"

, "Booking deadline"
: "Ostateczny termin rezerwacji"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Konto"

, "Time Account (Number - Title)"
: "Konto czasu (numer - tytuł)"

, "Billable"
: "Do przeliczenia"

, "Cleared"
: "Przeliczone"

, "Date"
: "Data"

, "Start time"
: "Czas rozpoczęcia"

, "End time"
: ""

, "Duration"
: "Czas trwania"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Konto godzin zamknięte"

, "Timetracker"
: "Zliczanie czasu"

, "Timeaccounts to bill"
: "Karty czasu pracy do przeliczenia"

, "Timeaccounts not yet billed"
: "Nieprzeliczone konta godzin"

, "Timeaccounts already billed"
: "Przeliczone konta godzin"

, "My Timesheets today"
: "Moje, dzisiejsze karty czasu pracy"

, "My Timesheets this week"
: "Moje karty czasu pracy z bieżącego tygodnia"

, "My Timesheets last week"
: "Moje karty czasu pracy z ubiegłego tygodnia"

, "My Timesheets this month"
: "Moje karty czasu pracy z bieżącego miesiąca"

, "My Timesheets last month"
: "Moje karty czasu pracy z ubiegłego miesiąca"

, "Manage timeaccounts"
: "Zarządzaj kontami godzin"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Dodaj, edytuj i usuń konta godzin (razem ze wszystkimi uprawnieniami do kart czasu pracy)"

, "Add timeaccounts"
: "Dodaj konta godzin"

, "Manage shared timeaccount favorites"
: "Zarządzaj wspólnymi ulubionymi śledzenia czasu"

, "Create or update shared timeaccount favorites"
: "Utwórz albo uaktualnij wspólne ulubione śledzenia czasu"

, "Manage shared timesheet favorites"
: "Zarządzaj wspólnymi ulubionymi śledzenia czasu"

, "Create or update shared timesheet favorites"
: "Utwórz albo uaktualnij wspólne ulubione śledzenia czasu"






, "Timesheet"
: "Karta czasu pracy"

, "Timeaccount"
: ""

, "Time Account"
: "Konto godzin"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
